@@ -1159,7 +1159,7 @@ class expint(Function):
     At half-integers it reduces to error functions:
 
     >>> expint(S(1)/2, z)
-    -sqrt(pi)*erf(sqrt(z))/sqrt(z) + sqrt(pi)/sqrt(z)
+    sqrt(pi)*erfc(sqrt(z))/sqrt(z)
 
     At positive integer orders it can be rewritten in terms of exponentials
     and expint(1, z). Use expand_func() to do this:
